.. _prosecutor:

.. title:: prosecutor

article 15
==========

Prosecutor

1. The Prosecutor may initiate investigations proprio motu on the basis of information on
crimes within the jurisdiction of the Court.

2. The Prosecutor shall analyse the seriousness of the information received. For this
purpose, he or she may seek additional information from States, organs of the United
Nations, intergovernmental or non-governmental organizations, or other reliable
sources that he or she deems appropriate, and may receive written or oral testimony at
the seat of the Court.

3. If the Prosecutor concludes that there is a reasonable basis to proceed with an
investigation, he or she shall submit to the Pre-Trial Chamber a request for
authorization of an investigation, together with any supporting material collected.
Victims may make representations to the Pre-Trial Chamber, in accordance with the
Rules of Procedure and Evidence.

4. If the Pre-Trial Chamber, upon examination of the request and the supporting material,
considers that there is a reasonable basis to proceed with an investigation, and that
the case appears to fall within the jurisdiction of the Court, it shall authorize the
commencement of the investigation, without prejudice to subsequent determinations
by the Court with regard to the jurisdiction and admissibility of a case.

5. The refusal of the Pre-Trial Chamber to authorize the investigation shall not preclude
the presentation of a subsequent request by the Prosecutor based on new facts or
evidence regarding the same situation.

6. If, after the preliminary examination referred to in paragraphs 1 and 2, the Prosecutor
concludes that the information provided does not constitute a reasonable basis for an
investigation, he or she shall inform those who provided the information. This shall
not preclude the Prosecutor from considering further information submitted to him or
her regarding the same situation in the light of new facts or evidence.
